@@ -1,5 +1,5 @@
 package Math::Shape::Point;
-$Math::Shape::Point::VERSION = '0.08';
+$Math::Shape::Point::VERSION = '0.09';
 use strict;
 use warnings;
 use Math::Trig ':pi';
@@ -10,6 +10,7 @@ use Carp 'croak';
 
 
 sub new {
+    croak 'Incorrect number of arguments for new()' unless @_ == 4;
     my ($class, $x, $y, $r) = @_;
     my $self = { 
         x => $x,
@@ -20,11 +21,11 @@ sub new {
 }
 
 
-sub getLocation { [$_[0]->{x}, $_[0]->{y}] }
+sub get_location { [$_[0]->{x}, $_[0]->{y}] }
 
 
 
-sub setLocation {
+sub set_location {
     my ($self, $x, $y) = @_;
     $self->{x} = $x;
     $self->{y} = $y;
@@ -32,13 +33,13 @@ sub setLocation {
 }
 
 
-sub getDirection {
+sub get_direction {
     return $_[0]->{r};
 }
 
 
-sub setDirection {
-    $_[0]->{r} = $_[0]->normalizeRadian($_[1]);
+sub set_direction {
+    $_[0]->{r} = $_[0]->normalize_radian($_[1]);
     1;
 }
 
@@ -51,14 +52,14 @@ sub advance {
 
 
 sub rotate {
-    $_[0]->{r} = $_[0]->{r} + $_[0]->normalizeRadian($_[1]);
+    $_[0]->{r} = $_[0]->{r} + $_[0]->normalize_radian($_[1]);
     1;
 }
 
 
-sub rotateAboutPoint {
+sub rotate_about_point {
     my ($self, $origin, $r) = @_;
-    $r = $self->normalizeRadian($r);
+    $r = $self->normalize_radian($r);
     $self->{x} = $origin->{x} + int(cos($r) * ($self->{x} - $origin->{x}) - sin($r) * ($self->{y} - $origin->{y}));
     $self->{y} = $origin->{y} + int(sin($r) * ($self->{x} - $origin->{x}) + cos($r) * ($self->{y} - $origin->{y}));
     $self->rotate($r);
@@ -66,17 +67,17 @@ sub rotateAboutPoint {
 }
 
 
-sub getDistanceToPoint {
+sub get_distance_to_point {
     sqrt ( abs($_[0]->{x} - $_[1]->{x}) ** 2 + abs($_[0]->{y} - $_[1]->{y}) ** 2);
 }
 
 
-sub getAngleToPoint {
+sub get_angle_to_point {
     my ($self, $p) = @_;
 
     # check points are not at the same location
-    if ($self->getLocation->[0] == $p->getLocation->[0]
-        && $self->getLocation->[1] == $p->getLocation->[1]) 
+    if ($self->get_location->[0] == $p->get_location->[0]
+        && $self->get_location->[1] == $p->get_location->[1]) 
     {
         croak 'Error: points are at the same location';
     }
@@ -84,20 +85,20 @@ sub getAngleToPoint {
     my $atan = atan2($p->{y} - $self->{y}, $p->{x} - $self->{x});
 
     if ($atan <= 0) { # lower half
-        return abs($atan) + pip2 + $self->getDirection;
+        return abs($atan) + pip2 + $self->get_direction;
     }
     elsif ($atan <= pip2)  { # upper right quadrant
-        return abs($atan - pip2) + $self->getDirection;
+        return abs($atan - pip2) + $self->get_direction;
     }
     else { # upper left quadrant
-        return pi2 - $atan + pip2 + $self->getDirection;
+        return pi2 - $atan + pip2 + $self->get_direction;
     }
 }
 
 
-sub getDirectionToPoint {
+sub get_direction_to_point {
     my ($self, $p) = @_;
-    my $angle = $self->getAngleToPoint($p);
+    my $angle = $self->get_angle_to_point($p);
     if    ($angle > 0 - pip4  && $angle <= pip4)      { return 'front' }
     elsif ($angle > pip4      && $angle <= pi - pip4) { return 'right' }
     elsif ($angle > pi - pip4 && $angle <= pi + pip4) { return 'back'  }
@@ -105,7 +106,7 @@ sub getDirectionToPoint {
 }
 
 
-sub normalizeRadian {
+sub normalize_radian {
     my ($self, $radians) = @_;
     my $piDecimal = ($radians / pi2 - int($radians / pi2));
     return $piDecimal < 0 ? pi2 + $piDecimal * pi2 : $piDecimal * pi2;
@@ -125,18 +126,18 @@ Math::Shape::Point - a 2d point object in cartesian space with utility angle met
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
     use Math::Shape::Point;
     use Math::Trig ':pi';
 
-    my $p0 = Math::Shape::Point->new(0, 0, 0);
-    my $p1 = Math::Shape::Point->new(5, 5, 0);
-    $p0->rotateAboutPoint($p1, pip2);
-    my $angle = $p0->getAngleToPoint($p1);
-    my $distance = $p0->getDistanceToPoint($p1);
+    my $p1 = Math::Shape::Point->new(0, 0, 0);
+    my $p2 = Math::Shape::Point->new(5, 5, 0);
+    $p1->rotate_about_point($p2, pip2);
+    my $angle = $p1->get_angle_to_point($p2);
+    my $distance = $p1->get_distance_to_point($p2);
 
 =head1 DESCRIPTION
 
@@ -151,47 +152,71 @@ This module is designed to provide some useful 2d functions for manipulating poi
 
 Instantiates a new point object. Requires the x and y cartesian coordinates and the facing direction in radians.
 
-=head2 getLocation
+    my $p = Math::Shape::Point->new(0, 0, 0);
+
+=head2 get_location
 
 Returns an arrayref containing the point's location in cartesian coordinates.
 
-=head2 setLocation
+    $p->get_location;
+
+=head2 set_location
 
 Sets the point's location in cartesian coordinates. Requires two numbers as inputs for the x and y location.
 
-=head2 getDirection
+    $p->set_location($x, $y);
+
+=head2 get_direction
 
 Returns the current facing direction in radians.
 
-=head2 setDirection
+    $p->get_direction;
+
+=head2 set_direction
 
 Sets the current facing direction in radians.
 
+    $p->set_direction(2.5);
+
 =head2 advance
 
 Requires a numeric distance argument - moves the point forward that distance in Cartesian coordinates towards the direction it is facing.
 
+    $p->advance(5);
+
 =head2 rotate
 
 Updates the point's facing direction by radians.
 
-=head2 rotateAboutPoint
+    $p->rotate(2);
+
+=head2 rotate_about_point
 
 Rotates the point around another point of origin. Requires a point object and the angle in radians to rotate. This method updates the facing direction of the point object, as well as it's location.
 
-=head2 getDistanceToPoint
+    my $p1 = Math::Shape::Point->new(0, 0, 0); #new point at 0,0 facing 0 radians.
+    my $p2 = Math::Shape::Point->new(1, 2, 3.14); #new point at 1,2 facing 3.14 radians.
+    $p1->rotate_about_point($p2, 3.14);
+
+=head2 get_distance_to_point
 
 Returns the distance to another point object. Requires a point object as an argument.
 
-=head2 getAngleToPoint
+    $p1->get_distance_to_point($p2);
+
+=head2 get_angle_to_point
 
 Returns the angle of another point object. Requires a point as an argument.
 
-=head2 getDirectionToPoint
+    $p1->get_angle_to_point($p2);
+
+=head2 get_direction_to_point
 
 Returns the direction of another point objection as a string (front, right, back or left). Assumes a 90 degree angle per direction.  Requires a point object as an argument.
 
-=head2 normalizeRadian
+    $p1->get_direction_to_point($p2); # front
+
+=head2 normalize_radian
 
 Takes a radian argument and returns it between 0 and PI2. Negative numbers are assumed to be backwards (e.g. -1.57 == PI + PI / 2)
 
@@ -202,7 +227,7 @@ David Farrell, C<< <davidnmfarrell at gmail.com> >>, L<perltricks.com|http://per
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-math-shape-point at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=math-shape-point>.  I will be notified, and then you'll automatically be notified of 
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=math-shape-point>.  I will be notified, and then you'll automatically be notified of
 progress on your bug as I make changes.
 
 =head1 SUPPORT
